@@ -146,7 +146,7 @@ class ApiList(View):
                 if vm:
                     datarec.update(vm)
                     resp = json_response(datarec)
-                    resp['Clear-Site-Data'] = '"*"'
+                    resp['Clear-Site-Data'] = '"cache", "storage"'
                     return resp
                 return json_response(datarec)
 
@@ -207,7 +207,7 @@ class ApiList(View):
             if vm:
                 kw.update(vm)
                 resp = json_response(kw)
-                resp['Clear-Site-Data'] = '"*"'
+                resp['Clear-Site-Data'] = '"cache", "storage"'
                 return resp
             return json_response(kw)
 
